@@ -208,8 +208,12 @@ class List(UserList):
         if self._wrapped_obj is None:
             return
         components = self._wrapped_obj.ContainedComponentsAsList
-        indices = sort_component_list(components)
-        return [x for _, x in sorted(zip(indices, components))]
+        try:
+            indices = sort_component_list(components)
+            return [x for _, x in sorted(zip(indices, components))]
+        except TypeError as e:
+            logger.warning(f'Could not sort list {components}:\n{e}')
+            return components
 
     def __getitem__(self, i):
         if isinstance(i, slice):
@@ -276,9 +280,14 @@ class ReferenceList(UserList):
     def data(self):
         if self._wrapped_obj is None:
             return
+
         ref_components = [x.Reference for x in self._wrapped_obj.ReferencedComponents.Items]
-        indices = sort_references(self._wrapped_obj.ReferencedComponents.Items)
-        return [x for _, x in sorted(zip(indices, ref_components))]
+        try:
+            indices = sort_references(self._wrapped_obj.ReferencedComponents.Items)
+            return [x for _, x in sorted(zip(indices, ref_components))]
+        except TypeError as e:
+            logger.warning(f'Could not sort list {ref_components}:\n{e}')
+            return ref_components
 
     @property
     def contained_components(self):
