@@ -1,6 +1,6 @@
-
+from .config import logger
 # from .config import yaml
-
+import re
 
 class classproperty(object):
 
@@ -231,3 +231,28 @@ def get_obj_by_id(cls, id):
     return cls._cls_instances_dict.get(id, None)
 
 
+def sort_component_list(components):
+
+    if components.__len__() == 0:
+        return components
+
+    slots = [x.FitsInSlots[0] for x in components]
+    if not all(slots[0] == x for x in slots):
+        raise TypeError(f'List elements do not have same slot')
+
+    slot_extensions = [int(re.findall("[-+]?[.]?[\d]+(?:,\d\d\d)*[\.]?\d*(?:[eE][-+]?\d+)?", x.CurrentSlot)[-1]) for x in components]
+    return slot_extensions
+
+
+def sort_references(references):
+
+    if references.__len__() == 0:
+        return references
+    # check if same slot:
+    slots = [x.ReferenceFunction.SlotBase for x in references]
+
+    if not all(slots[0] == x for x in slots):
+        raise TypeError(f'List elements do not have same slot')
+
+    slot_extensions = [int(x.ReferenceFunction.SlotExtension) for x in references]
+    return slot_extensions
